@@ -313,14 +313,16 @@ class RDSClient():
                                  results_file_uri: str):
         """
         """
-        query = f"UPDATE neuralplatform_model SET resultsFileUri = {results_file_uri} WHERE id = {model_id};"
+        query = f"UPDATE neuralplatform_model SET resultsFileUri = '{results_file_uri}' WHERE id = {model_id};"
+        return self.update_query(query)
     
     def update_model_uri(self, 
                          model_id: int,
                          model_uri: str):
         """
         """
-        query = f"UPDATE neuralplatform_model SET modelUri = {model_uri} WHERE id = {model_id};"
+        query = f"UPDATE neuralplatform_model SET modelUri = '{model_uri}'' WHERE id = {model_id};"
+        return self.update_query(query)
     
     def get_version_model(self,
                           version_id: int) -> dict:
@@ -360,8 +362,7 @@ class RDSClient():
                                 version_id: int) -> dict:
         """
         """
-        query = f"SELECT id FROM neuralplatform_model WHERE version_id = {version_id};"
-        model_id = self.select_query(query, fetchone=True) ['id']
+        model_id = self.get_version_model(version_id)['id']
         query = f"SELECT classDefinition_id, minConfidence FROM neuralplatform_classperformance WHERE model_id = {model_id};"
         return { r['classDefinition_id'] : r['minConfidence'] for r in self.select_query(query, fetchone=False) }
     
