@@ -68,6 +68,7 @@ class SQSClient(Boto3Client):
         msg_body = query
         self.send_message(
             QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/rds-queries-queue.fifo",
-            MessageBody=msg_body
+            MessageBody=msg_body,
+            MessageGroupId="1"
         )
         
\ No newline at end of file
